@@ -207,23 +207,23 @@ class InternetDynamicFields():
             return DynamicField(name="notes", value=self.eticom_contract.notes)
 
     def _df_adsl_coverage(self):
-        if self.eticom_contract.coverage_availability and self.eticom_contract.coverage_availability.adsl_coverage:
-            return DynamicField(name="coberturaADSL", value=self.eticom_contract.coverage_availability.adsl_coverage)
+        if self.eticom_contract.coverage_availability and self.eticom_contract.coverage_availability.adsl:
+            return DynamicField(name="coberturaADSL", value=self.eticom_contract.coverage_availability.adsl)
 
     def _df_mm_fiber_coverage(self):
-        if self.eticom_contract.coverage_availability and self.eticom_contract.coverage_availability.mm_fiber_coverage:
+        if self.eticom_contract.coverage_availability and self.eticom_contract.coverage_availability.mm_fiber:
             return DynamicField(
                 name="coberturaFibraMM",
-                value=self.eticom_contract.coverage_availability.mm_fiber_coverage
+                value=self.eticom_contract.coverage_availability.mm_fiber
             )
 
     def _df_vdf_fiber_coverage(self):
-        if self.eticom_contract.coverage_availability and self.eticom_contract.coverage_availability.vdf_fiber_coverage:
+        if self.eticom_contract.coverage_availability and self.eticom_contract.coverage_availability.vdf_fiber:
             return DynamicField(
                 name="coberturaFibraVdf",
-                value=self.eticom_contract.coverage_availability.vdf_fiber_coverage
+                value=self.eticom_contract.coverage_availability.vdf_fiber
             )
 
     def _df_change_address(self):
         if self.eticom_contract.change_address:
-            return DynamicField(name="canviUbicaciomateixTitular", value="yes")
+            return DynamicField(name="canviUbicacioMateixTitular", value="yes")
