@@ -128,7 +128,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
         self.assertEquals(ticket.id, 234)
 
     @patch('otrs_somconnexio.otrs_models.internet_ticket.OTRSClient')
-    def test_create_fibre_ticket_factory(self, MockOTRSClient):
+    def test_create_fiber_ticket_factory(self, MockOTRSClient):
         contract_type = 'fiber'
 
         eticom_contract = Mock(spec=[
@@ -169,12 +169,12 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'adsl_process_id'
             'adsl_activity_id'
         ])
-        otrs_configuration.fibre_ticket_type = 'fiber'
-        otrs_configuration.fibre_ticket_queue = 'fiber_queue'
-        otrs_configuration.fibre_ticket_state = 'fiber_state'
-        otrs_configuration.fibre_ticket_proprity = 'fiber_proprity'
-        otrs_configuration.fibre_process_id = 'fiber_process_id'
-        otrs_configuration.fibre_activity_id = 'fiber_activity_id'
+        otrs_configuration.fiber_ticket_type = 'fiber'
+        otrs_configuration.fiber_ticket_queue = 'fiber_queue'
+        otrs_configuration.fiber_ticket_state = 'fiber_state'
+        otrs_configuration.fiber_ticket_proprity = 'fiber_proprity'
+        otrs_configuration.fiber_process_id = 'fiber_process_id'
+        otrs_configuration.fiber_activity_id = 'fiber_activity_id'
 
         otrs_process_ticket = Mock(spec=['id'])
         otrs_process_ticket.id = 234
