@@ -152,7 +152,7 @@ class MobileTicketTestCase(unittest.TestCase):
         mock_mobile_dynamic_fields.all.assert_called_once()
 
     @patch('otrs_somconnexio.otrs_models.mobile_ticket.OTRSClient')
-    def test_build(self, MockOTRSClient):
+    def test_create(self, MockOTRSClient):
         eticom_contract = Mock(spec=[
             'id',
             'party'
@@ -185,9 +185,16 @@ class MobileTicketTestCase(unittest.TestCase):
         ])
 
         mock_otrs_client = Mock(spec=['create_otrs_process_ticket'])
+        mock_otrs_client.create_otrs_process_ticket.return_value = Mock(MobileTicket, autospec=True)
+        mock_otrs_client.create_otrs_process_ticket.return_value.id = 123
+        mock_otrs_client.create_otrs_process_ticket.return_value.number = '#123'
         MockOTRSClient.return_value = mock_otrs_client
 
-        MobileTicket(eticom_contract, otrs_configuration).build()
+        ticket = MobileTicket(eticom_contract, otrs_configuration)
+        ticket.create()
 
         MockOTRSClient.assert_called_once_with()
         mock_otrs_client.create_otrs_process_ticket.assert_called_once()
+
+        self.assertEqual(ticket.id, 123)
+        self.assertEqual(ticket.number, '#123')
