@@ -25,12 +25,12 @@ class TicketFactoryTestCase(unittest.TestCase):
     def setUp(self):
         self.eticom_contract = Mock(spec=['id'])
         self.otrs_configuration = Mock(spec=[
-            'fibre_ticket_type',
-            'fibre_ticket_queue',
-            'fibre_ticket_state',
-            'fibre_ticket_priority',
-            'fibre_process_id',
-            'fibre_activity_id',
+            'fiber_ticket_type',
+            'fiber_ticket_queue',
+            'fiber_ticket_state',
+            'fiber_ticket_priority',
+            'fiber_process_id',
+            'fiber_activity_id',
             'adsl_ticket_type',
             'adsl_ticket_queue',
             'adsl_ticket_state',
@@ -56,12 +56,12 @@ class TicketFactoryTestCase(unittest.TestCase):
         self.otrs_configuration.adsl_ticket_proprity = 'adsl_ticket_priority'
         self.otrs_configuration.adsl_process_id = 'adsl_process_id'
         self.otrs_configuration.adsl_activity_id = 'adsl_activity_id'
-        self.otrs_configuration.fibre_ticket_type = 'fiber_ticket_type'
-        self.otrs_configuration.fibre_ticket_queue = 'fiber_ticket_queue'
-        self.otrs_configuration.fibre_ticket_state = 'fiber_ticket_state'
-        self.otrs_configuration.fibre_ticket_proprity = 'fiber_ticket_priority'
-        self.otrs_configuration.fibre_process_id = 'fiber_process_id'
-        self.otrs_configuration.fibre_activity_id = 'fiber_activity_id'
+        self.otrs_configuration.fiber_ticket_type = 'fiber_ticket_type'
+        self.otrs_configuration.fiber_ticket_queue = 'fiber_ticket_queue'
+        self.otrs_configuration.fiber_ticket_state = 'fiber_ticket_state'
+        self.otrs_configuration.fiber_ticket_proprity = 'fiber_ticket_priority'
+        self.otrs_configuration.fiber_process_id = 'fiber_process_id'
+        self.otrs_configuration.fiber_activity_id = 'fiber_activity_id'
 
     def test_build_raise_service_type_not_allowed_error(self):
         ticket_factory = TicketFactory(
